DualstackMeasureManyStream

Struct DualstackMeasureManyStream 

pub struct DualstackMeasureManyStream<'a, I: Iterator<Item = IpAddr>> { /* private fields */ }
A Stream of ping responses.

No kind of rtt timeout is implemented, so an external mechanism like tokio::time::timeout should be used to prevent the program from hanging indefinitely.

Leaking this method might crate a slowly forever growing memory leak.

Implementations

Source

impl<I: Iterator<Item = IpAddr>> DualstackMeasureManyStream<'_, I>

pub fn poll_next_unpin( &mut self, cx: &mut Context<'_>, ) -> Poll<Option<(IpAddr, Duration)>>